@@ -9,7 +9,7 @@ import (
 func AgeSecretKey() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Age secret key",
+		Description: "Discovered a potential Age encryption tool secret key, risking data decryption and unauthorized access to sensitive information.",
 		RuleID:      "age secret key",
 		Regex:       regexp.MustCompile(`AGE-SECRET-KEY-1[QPZRY9X8GF2TVDW0S3JN54KHCE6MUA7L]{58}`),
 		Keywords:    []string{"AGE-SECRET-KEY-1"},
