@@ -9,7 +9,7 @@ func ConfluentSecretKey() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "confluent-secret-key",
-		Description: "Confluent Secret Key",
+		Description: "Found a Confluent Secret Key, potentially risking unauthorized operations and data access within Confluent services.",
 		Regex:       generateSemiGenericRegex([]string{"confluent"}, alphaNumeric("64"), true),
 		Keywords: []string{
 			"confluent",
@@ -27,7 +27,7 @@ func ConfluentAccessToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "confluent-access-token",
-		Description: "Confluent Access Token",
+		Description: "Identified a Confluent Access Token, which could compromise access to streaming data platforms and sensitive data flow.",
 		Regex:       generateSemiGenericRegex([]string{"confluent"}, alphaNumeric("16"), true),
 
 		Keywords: []string{
