@@ -8,7 +8,7 @@ import (
 func DropBoxAPISecret() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Dropbox API secret",
+		Description: "Identified a Dropbox API secret, which could lead to unauthorized file access and data breaches in Dropbox storage.",
 		RuleID:      "dropbox-api-token",
 		Regex:       generateSemiGenericRegex([]string{"dropbox"}, alphaNumeric("15"), true),
 
@@ -26,7 +26,7 @@ func DropBoxShortLivedAPIToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "dropbox-short-lived-api-token",
-		Description: "Dropbox short lived API token",
+		Description: "Discovered a Dropbox short-lived API token, posing a risk of temporary but potentially harmful data access and manipulation.",
 		Regex:       generateSemiGenericRegex([]string{"dropbox"}, `sl\.[a-z0-9\-=_]{135}`, true),
 		Keywords:    []string{"dropbox"},
 	}
@@ -39,7 +39,7 @@ func DropBoxLongLivedAPIToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "dropbox-long-lived-api-token",
-		Description: "Dropbox long lived API token",
+		Description: "Found a Dropbox long-lived API token, risking prolonged unauthorized access to cloud storage and sensitive data.",
 		Regex:       generateSemiGenericRegex([]string{"dropbox"}, `[a-z0-9]{11}(AAAAAAAAAA)[a-z0-9\-_=]{43}`, true),
 		Keywords:    []string{"dropbox"},
 	}
