@@ -10,7 +10,7 @@ import (
 func EasyPost() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "EasyPost API token",
+		Description: "Identified an EasyPost API token, which could lead to unauthorized postal and shipment service access and data exposure.",
 		RuleID:      "easypost-api-token",
 		Regex:       regexp.MustCompile(`\bEZAK(?i)[a-z0-9]{54}`),
 		Keywords:    []string{"EZAK"},
@@ -26,7 +26,7 @@ func EasyPost() *config.Rule {
 func EasyPostTestAPI() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "EasyPost test API token",
+		Description: "Detected an EasyPost test API token, risking exposure of test environments and potentially sensitive shipment data.",
 		RuleID:      "easypost-test-api-token",
 		Regex:       regexp.MustCompile(`\bEZTK(?i)[a-z0-9]{54}`),
 		Keywords:    []string{"EZTK"},
