@@ -8,7 +8,7 @@ import (
 func Facebook() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Facebook Access Token",
+		Description: "Discovered a Facebook Access Token, posing a risk of unauthorized access to Facebook accounts and personal data exposure.",
 		RuleID:      "facebook",
 		Regex:       generateSemiGenericRegex([]string{"facebook"}, hex("32"), true),
 
