@@ -10,7 +10,7 @@ import (
 func FlutterwavePublicKey() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Finicity Public Key",
+		Description: "Detected a Finicity Public Key, potentially exposing public cryptographic operations and integrations.",
 		RuleID:      "flutterwave-public-key",
 		Regex:       regexp.MustCompile(`FLWPUBK_TEST-(?i)[a-h0-9]{32}-X`),
 		Keywords:    []string{"FLWPUBK_TEST"},
@@ -26,7 +26,7 @@ func FlutterwavePublicKey() *config.Rule {
 func FlutterwaveSecretKey() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Flutterwave Secret Key",
+		Description: "Identified a Flutterwave Secret Key, risking unauthorized financial transactions and data breaches.",
 		RuleID:      "flutterwave-secret-key",
 		Regex:       regexp.MustCompile(`FLWSECK_TEST-(?i)[a-h0-9]{32}-X`),
 		Keywords:    []string{"FLWSECK_TEST"},
@@ -42,7 +42,7 @@ func FlutterwaveSecretKey() *config.Rule {
 func FlutterwaveEncKey() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Flutterwave Encryption Key",
+		Description: "Uncovered a Flutterwave Encryption Key, which may compromise payment processing and sensitive financial information.",
 		RuleID:      "flutterwave-encryption-key",
 		Regex:       regexp.MustCompile(`FLWSECK_TEST-(?i)[a-h0-9]{12}`),
 		Keywords:    []string{"FLWSECK_TEST"},
