@@ -9,7 +9,7 @@ func FreshbooksAccessToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "freshbooks-access-token",
-		Description: "Freshbooks Access Token",
+		Description: "Discovered a Freshbooks Access Token, posing a risk to accounting software access and sensitive financial data exposure.",
 		Regex:       generateSemiGenericRegex([]string{"freshbooks"}, alphaNumeric("64"), true),
 
 		Keywords: []string{
