@@ -8,7 +8,7 @@ func GenericCredential() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "generic-api-key",
-		Description: "Generic API Key",
+		Description: "Detected a Generic API Key, potentially exposing access to various services and sensitive operations.",
 		Regex: generateSemiGenericRegex([]string{
 			"key",
 			"api",
