@@ -10,7 +10,7 @@ import (
 func GitHubPat() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "GitHub Personal Access Token",
+		Description: "Uncovered a GitHub Personal Access Token, potentially leading to unauthorized repository access and sensitive content exposure.",
 		RuleID:      "github-pat",
 		Regex:       regexp.MustCompile(`ghp_[0-9a-zA-Z]{36}`),
 		Keywords:    []string{"ghp_"},
@@ -26,7 +26,7 @@ func GitHubPat() *config.Rule {
 func GitHubFineGrainedPat() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "GitHub Fine-Grained Personal Access Token",
+		Description: "Found a GitHub Fine-Grained Personal Access Token, risking unauthorized repository access and code manipulation.",
 		RuleID:      "github-fine-grained-pat",
 		Regex:       regexp.MustCompile(`github_pat_[0-9a-zA-Z_]{82}`),
 		Keywords:    []string{"github_pat_"},
@@ -42,7 +42,7 @@ func GitHubFineGrainedPat() *config.Rule {
 func GitHubOauth() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "GitHub OAuth Access Token",
+		Description: "Discovered a GitHub OAuth Access Token, posing a risk of compromised GitHub account integrations and data leaks.",
 		RuleID:      "github-oauth",
 		Regex:       regexp.MustCompile(`gho_[0-9a-zA-Z]{36}`),
 		Keywords:    []string{"gho_"},
@@ -58,7 +58,7 @@ func GitHubOauth() *config.Rule {
 func GitHubApp() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "GitHub App Token",
+		Description: "Identified a GitHub App Token, which may compromise GitHub application integrations and source code security.",
 		RuleID:      "github-app-token",
 		Regex:       regexp.MustCompile(`(ghu|ghs)_[0-9a-zA-Z]{36}`),
 		Keywords:    []string{"ghu_", "ghs_"},
@@ -75,7 +75,7 @@ func GitHubApp() *config.Rule {
 func GitHubRefresh() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "GitHub Refresh Token",
+		Description: "Detected a GitHub Refresh Token, which could allow prolonged unauthorized access to GitHub services.",
 		RuleID:      "github-refresh-token",
 		Regex:       regexp.MustCompile(`ghr_[0-9a-zA-Z]{36}`),
 		Keywords:    []string{"ghr_"},
