@@ -9,7 +9,7 @@ func GoCardless() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "gocardless-api-token",
-		Description: "GoCardless API token",
+		Description: "Detected a GoCardless API token, potentially risking unauthorized direct debit payment operations and financial data exposure.",
 		Regex:       generateSemiGenericRegex([]string{"gocardless"}, `live_(?i)[a-z0-9\-_=]{40}`, true),
 
 		Keywords: []string{
