@@ -7,7 +7,7 @@ import (
 func Heroku() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Heroku API Key",
+		Description: "Detected a Heroku API Key, potentially compromising cloud application deployments and operational security.",
 		RuleID:      "heroku-api-key",
 		Regex:       generateSemiGenericRegex([]string{"heroku"}, hex8_4_4_4_12(), true),
 
