@@ -7,7 +7,7 @@ import (
 func HubSpot() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "HubSpot API Token",
+		Description: "Found a HubSpot API Token, posing a risk to CRM data integrity and unauthorized marketing operations.",
 		RuleID:      "hubspot-api-key",
 		Regex: generateSemiGenericRegex([]string{"hubspot"},
 			`[0-9A-F]{8}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{12}`, true),
