@@ -13,7 +13,7 @@ func JFrogAPIKey() *config.Rule {
 	// Define Rule
 	r := config.Rule{
 		// Human readable description of the rule
-		Description: "JFrog API Key",
+		Description: "Found a JFrog API Key, posing a risk of unauthorized access to software artifact repositories and build pipelines.",
 
 		// Unique ID for the rule
 		RuleID: "jfrog-api-key",
@@ -39,7 +39,7 @@ func JFrogIdentityToken() *config.Rule {
 	// Define Rule
 	r := config.Rule{
 		// Human readable description of the rule
-		Description: "JFrog Identity Token",
+		Description: "Discovered a JFrog Identity Token, potentially compromising access to JFrog services and sensitive software artifacts.",
 
 		// Unique ID for the rule
 		RuleID: "jfrog-identity-token",
