@@ -9,7 +9,7 @@ func LaunchDarklyAccessToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "launchdarkly-access-token",
-		Description: "Launchdarkly Access Token",
+		Description: "Uncovered a Launchdarkly Access Token, potentially compromising feature flag management and application functionality.",
 		Regex:       generateSemiGenericRegex([]string{"launchdarkly"}, alphaNumericExtended("40"), true),
 
 		Keywords: []string{
