@@ -9,7 +9,7 @@ func OpenAI() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "openai-api-key",
-		Description: "OpenAI API Key",
+		Description: "Found an OpenAI API Key, posing a risk of unauthorized access to AI services and data manipulation.",
 		Regex:       generateUniqueTokenRegex(`sk-[a-zA-Z0-9]{20}T3BlbkFJ[a-zA-Z0-9]{20}`, true),
 
 		Keywords: []string{
