@@ -9,7 +9,7 @@ func PlanetScalePassword() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "planetscale-password",
-		Description: "PlanetScale password",
+		Description: "Discovered a PlanetScale password, which could lead to unauthorized database operations and data breaches.",
 		Regex:       generateUniqueTokenRegex(`pscale_pw_(?i)[a-z0-9=\-_\.]{32,64}`, true),
 
 		Keywords: []string{
@@ -30,7 +30,7 @@ func PlanetScaleAPIToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "planetscale-api-token",
-		Description: "PlanetScale API token",
+		Description: "Identified a PlanetScale API token, potentially compromising database management and operations.",
 		Regex:       generateUniqueTokenRegex(`pscale_tkn_(?i)[a-z0-9=\-_\.]{32,64}`, true),
 
 		Keywords: []string{
@@ -51,7 +51,7 @@ func PlanetScaleOAuthToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "planetscale-oauth-token",
-		Description: "PlanetScale OAuth token",
+		Description: "Found a PlanetScale OAuth token, posing a risk to database access control and sensitive data integrity.",
 		Regex:       generateUniqueTokenRegex(`pscale_oauth_(?i)[a-z0-9=\-_\.]{32,64}`, true),
 
 		Keywords: []string{
