@@ -10,7 +10,7 @@ import (
 func ScalingoAPIToken() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Scalingo API token",
+		Description: "Found a Scalingo API token, posing a risk to cloud platform services and application deployment security.",
 		RuleID:      "scalingo-api-token",
 		Regex:       regexp.MustCompile(`\btk-us-[a-zA-Z0-9-_]{48}\b`),
 		Keywords:    []string{"tk-us-"},
