@@ -9,7 +9,7 @@ func SendInBlueAPIToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "sendinblue-api-token",
-		Description: "Sendinblue API token",
+		Description: "Identified a Sendinblue API token, which may compromise email marketing services and subscriber data privacy.",
 		Regex:       generateUniqueTokenRegex(`xkeysib-[a-f0-9]{64}\-(?i)[a-z0-9]{16}`, true),
 
 		Keywords: []string{
