@@ -9,7 +9,7 @@ func SentryAccessToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "sentry-access-token",
-		Description: "Sentry Access Token",
+		Description: "Found a Sentry Access Token, risking unauthorized access to error tracking services and sensitive application data.",
 		Regex:       generateSemiGenericRegex([]string{"sentry"}, hex("64"), true),
 
 		Keywords: []string{
