@@ -9,7 +9,7 @@ func ShippoAPIToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "shippo-api-token",
-		Description: "Shippo API token",
+		Description: "Discovered a Shippo API token, potentially compromising shipping services and customer order data.",
 		Regex:       generateUniqueTokenRegex(`shippo_(live|test)_[a-f0-9]{40}`, true),
 
 		Keywords: []string{
