@@ -16,7 +16,7 @@ func Snyk() *config.Rule {
 
 	// define rule
 	r := config.Rule{
-		Description: "Snyk API token",
+		Description: "Uncovered a Snyk API token, potentially compromising software vulnerability scanning and code security.",
 		RuleID:      "snyk-api-token",
 
 		Regex:    generateSemiGenericRegex(keywords, hex8_4_4_4_12(), true),
