@@ -9,7 +9,7 @@ func SquareSpaceAccessToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "squarespace-access-token",
-		Description: "Squarespace Access Token",
+		Description: "Identified a Squarespace Access Token, which may compromise website management and content control on Squarespace.",
 		Regex:       generateSemiGenericRegex([]string{"squarespace"}, hex8_4_4_4_12(), true),
 
 		Keywords: []string{
