@@ -11,7 +11,7 @@ func SumoLogicAccessID() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "sumologic-access-id",
-		Description: "SumoLogic Access ID",
+		Description: "Discovered a SumoLogic Access ID, potentially compromising log management services and data analytics integrity.",
 		// TODO: Make 'su' case-sensitive.
 		Regex: generateSemiGenericRegex([]string{"sumo"},
 			"su[a-zA-Z0-9]{12}", false),
@@ -54,7 +54,7 @@ func SumoLogicAccessToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "sumologic-access-token",
-		Description: "SumoLogic Access Token",
+		Description: "Uncovered a SumoLogic Access Token, which could lead to unauthorized access to log data and analytics insights.",
 		Regex: generateSemiGenericRegex([]string{"sumo"},
 			alphaNumeric("64"), true),
 
