@@ -10,7 +10,7 @@ import (
 func TeamsWebhook() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Microsoft Teams Webhook",
+		Description: "Uncovered a Microsoft Teams Webhook, which could lead to unauthorized access to team collaboration tools and data leaks.",
 		RuleID:      "microsoft-teams-webhook",
 		Regex: regexp.MustCompile(
 			`https:\/\/[a-z0-9]+\.webhook\.office\.com\/webhookb2\/[a-z0-9]{8}-([a-z0-9]{4}-){3}[a-z0-9]{12}@[a-z0-9]{8}-([a-z0-9]{4}-){3}[a-z0-9]{12}\/IncomingWebhook\/[a-z0-9]{32}\/[a-z0-9]{8}-([a-z0-9]{4}-){3}[a-z0-9]{12}`),
