@@ -10,7 +10,7 @@ import (
 func Twilio() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Twilio API Key",
+		Description: "Found a Twilio API Key, posing a risk to communication services and sensitive customer interaction data.",
 		RuleID:      "twilio-api-key",
 		Regex:       regexp.MustCompile(`SK[0-9a-fA-F]{32}`),
 		Keywords:    []string{"twilio"},
